TextAccum

Struct TextAccum 

pub struct TextAccum<'p> { /* private fields */ }
Utility class for accumulating tokens into a string, keeping a combined span that contains (in theory) all the tokens accumulated. This class is a hack used to bridge our LALRPOP parser, which operates on strings, with the user’s code. What we should really do is modify the LALRPOP parser to operate on tokens directly, but that’s for later.

Implementations

Source

impl<'p> TextAccum<'p>

pub fn new(parser: &'p mut Parser, t0: TokenTree) -> Self

pub fn accum(&mut self) -> Option<TokenTree>

Accumulate next token into the internal buffer and return it.

pub fn accum_if( &mut self, test: impl Fn(&TokenTree) -> bool, ) -> Option<TokenTree>

If the next token passes test, accumulates it into the internal buffer, and returns it.

pub fn into_accumulated_result(self) -> (String, Span)

Return the string we accumulated.