pub enum MethodSelector {
ClassName(JavaPath),
MethodName(JavaPath, Ident),
ClassInfo(ClassInfo),
}Expand description
There are various points where the user must select a method. In these cases, we permit them to either write just a class name (in which case we search for (hopefully) at most one such method), a class + method name, or a little mini class declaration that includes the full details (which accommodates the case where it is overloaded).
Variants
ClassName(JavaPath)
User wrote foo.bar.Baz
MethodName(JavaPath, Ident)
User wrote foo.bar.Baz::method
ClassInfo(ClassInfo)
User wrote class Foo { ... } with full details.
This class should have at most one member.
Implementations
Sourceimpl MethodSelector
impl MethodSelector
Sourcepub fn class_span(&self) -> Span
pub fn class_span(&self) -> Span
Span for things that refer to the class the method is in
pub fn class_name(&self) -> DotId
Sourcepub fn method_name(&self) -> String
pub fn method_name(&self) -> String
Returns the name of the method